@@ -18,7 +18,6 @@ import time
 from unittest import mock
 
 from oslo_utils import uuidutils
-import six
 import testtools
 
 from taskflow import exceptions as excp
@@ -33,6 +32,7 @@ from taskflow.utils import redis_utils as ru
 
 REDIS_AVAILABLE = test_utils.redis_available(
     impl_redis.RedisJobBoard.MIN_REDIS_VERSION)
+REDIS_PORT = test_utils.REDIS_PORT
 
 
 @testtools.skipIf(not REDIS_AVAILABLE, 'redis is not available')
@@ -42,9 +42,9 @@ class RedisJobboardTest(test.TestCase, base.BoardTestMixin):
 
     def create_board(self, persistence=None):
         namespace = uuidutils.generate_uuid()
-        client = ru.RedisClient()
+        client = ru.RedisClient(port=REDIS_PORT)
         config = {
-            'namespace': six.b("taskflow-%s" % namespace),
+            'namespace': ("taskflow-%s" % namespace).encode('latin-1'),
         }
         kwargs = {
             'client': client,
@@ -107,12 +107,14 @@ class RedisJobboardTest(test.TestCase, base.BoardTestMixin):
     def test__make_client(self):
         conf = {'host': '127.0.0.1',
                 'port': 6379,
+                'username': 'default',
                 'password': 'secret',
                 'namespace': 'test'
                 }
         test_conf = {
             'host': '127.0.0.1',
             'port': 6379,
+            'username': 'default',
             'password': 'secret',
         }
         with mock.patch('taskflow.utils.redis_utils.RedisClient') as mock_ru:
@@ -122,17 +124,72 @@ class RedisJobboardTest(test.TestCase, base.BoardTestMixin):
     def test__make_client_sentinel(self):
         conf = {'host': '127.0.0.1',
                 'port': 26379,
+                'username': 'default',
                 'password': 'secret',
                 'namespace': 'test',
                 'sentinel': 'mymaster',
-                'sentinel_kwargs': {'password': 'senitelsecret'}}
+                'sentinel_kwargs': {
+                    'username': 'default',
+                    'password': 'senitelsecret'
+                }}
         with mock.patch('redis.sentinel.Sentinel') as mock_sentinel:
             impl_redis.RedisJobBoard('test-board', conf)
             test_conf = {
+                'username': 'default',
                 'password': 'secret',
             }
             mock_sentinel.assert_called_once_with(
                 [('127.0.0.1', 26379)],
-                sentinel_kwargs={'password': 'senitelsecret'},
+                sentinel_kwargs={
+                    'username': 'default',
+                    'password': 'senitelsecret'
+                },
+                **test_conf)
+            mock_sentinel().master_for.assert_called_once_with('mymaster')
+
+    def test__make_client_sentinel_fallbacks(self):
+        conf = {'host': '127.0.0.1',
+                'port': 26379,
+                'username': 'default',
+                'password': 'secret',
+                'namespace': 'test',
+                'sentinel': 'mymaster',
+                'sentinel_fallbacks': [
+                    '[::1]:26379', '127.0.0.2:26379', 'localhost:26379'
+                ]}
+        with mock.patch('redis.sentinel.Sentinel') as mock_sentinel:
+            impl_redis.RedisJobBoard('test-board', conf)
+            test_conf = {
+                'username': 'default',
+                'password': 'secret',
+                'sentinel_kwargs': None,
+            }
+            mock_sentinel.assert_called_once_with(
+                [('127.0.0.1', 26379), ('::1', 26379),
+                 ('127.0.0.2', 26379), ('localhost', 26379)],
+                **test_conf)
+            mock_sentinel().master_for.assert_called_once_with('mymaster')
+
+    def test__make_client_sentinel_ssl(self):
+        conf = {'host': '127.0.0.1',
+                'port': 26379,
+                'username': 'default',
+                'password': 'secret',
+                'namespace': 'test',
+                'sentinel': 'mymaster',
+                'sentinel_kwargs': None,
+                'ssl': True,
+                'ssl_ca_certs': '/etc/ssl/certs'}
+        with mock.patch('redis.sentinel.Sentinel') as mock_sentinel:
+            impl_redis.RedisJobBoard('test-board', conf)
+            test_conf = {
+                'username': 'default',
+                'password': 'secret',
+                'ssl': True,
+                'ssl_ca_certs': '/etc/ssl/certs',
+            }
+            mock_sentinel.assert_called_once_with(
+                [('127.0.0.1', 26379)],
+                sentinel_kwargs=None,
                 **test_conf)
             mock_sentinel().master_for.assert_called_once_with('mymaster')
