@@ -14,13 +14,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import pickle
 import sys
 
-from oslo_utils import encodeutils
-import six
-from six.moves import cPickle as pickle
-import testtools
-
 from taskflow import exceptions
 from taskflow import test
 from taskflow.tests import utils as test_utils
@@ -64,13 +60,13 @@ class GeneralFailureObjTestsMixin(object):
 
     def test_check_str_not_there(self):
         val = 'ValueError'
-        self.assertEqual(None, self.fail_obj.check(val))
+        self.assertIsNone(self.fail_obj.check(val))
 
     def test_check_type(self):
         self.assertIs(self.fail_obj.check(RuntimeError), RuntimeError)
 
     def test_check_type_not_there(self):
-        self.assertIs(self.fail_obj.check(ValueError), None)
+        self.assertIsNone(self.fail_obj.check(ValueError))
 
 
 class CaptureFailureTestCase(test.TestCase, GeneralFailureObjTestsMixin):
@@ -89,7 +85,7 @@ class CaptureFailureTestCase(test.TestCase, GeneralFailureObjTestsMixin):
         self.assertIs(exc_info[1], self.fail_obj.exception)
 
     def test_reraises(self):
-        self.assertRaisesRegexp(RuntimeError, '^Woot!$', self.fail_obj.reraise)
+        self.assertRaisesRegex(RuntimeError, '^Woot!$', self.fail_obj.reraise)
 
 
 class ReCreatedFailureTestCase(test.TestCase, GeneralFailureObjTestsMixin):
@@ -102,10 +98,10 @@ class ReCreatedFailureTestCase(test.TestCase, GeneralFailureObjTestsMixin):
                                         exc_type_names=list(fail_obj))
 
     def test_value_lost(self):
-        self.assertIs(self.fail_obj.exception, None)
+        self.assertIsNone(self.fail_obj.exception)
 
     def test_no_exc_info(self):
-        self.assertIs(self.fail_obj.exc_info, None)
+        self.assertIsNone(self.fail_obj.exc_info)
 
     def test_pformat_traceback(self):
         text = self.fail_obj.pformat(traceback=True)
@@ -205,12 +201,12 @@ class FailureObjectTestCase(test.TestCase):
         self.assertEqual(expected, str(exc))
 
     def test_empty_does_not_reraise(self):
-        self.assertIs(failure.Failure.reraise_if_any([]), None)
+        self.assertIsNone(failure.Failure.reraise_if_any([]))
 
     def test_reraises_one(self):
         fls = [_captured_failure('Woot!')]
-        self.assertRaisesRegexp(RuntimeError, '^Woot!$',
-                                failure.Failure.reraise_if_any, fls)
+        self.assertRaisesRegex(RuntimeError, '^Woot!$',
+                               failure.Failure.reraise_if_any, fls)
 
     def test_reraises_several(self):
         fls = [
@@ -269,7 +265,7 @@ class FailureObjectTestCase(test.TestCase):
 
     def test_compares_to_none(self):
         captured = _captured_failure('Woot!')
-        self.assertNotEqual(captured, None)
+        self.assertIsNotNone(captured)
         self.assertFalse(captured.matches(None))
 
     def test_pformat_traceback(self):
@@ -306,7 +302,7 @@ class WrappedFailureTestCase(test.TestCase):
         fail_obj = _captured_failure('Woot!')
         wf = exceptions.WrappedFailure([fail_obj])
         self.assertEqual(RuntimeError, wf.check(RuntimeError))
-        self.assertEqual(None, wf.check(ValueError))
+        self.assertIsNone(wf.check(ValueError))
 
     def test_two_failures(self):
         fls = [
@@ -336,35 +332,27 @@ class NonAsciiExceptionsTestCase(test.TestCase):
         bad_string = chr(200)
         excp = ValueError(bad_string)
         fail = failure.Failure.from_exception(excp)
-        self.assertEqual(encodeutils.exception_to_unicode(excp),
-                         fail.exception_str)
-        # This is slightly different on py2 vs py3... due to how
-        # __str__ or __unicode__ is called and what is expected from
-        # both...
-        if six.PY2:
-            msg = encodeutils.exception_to_unicode(excp)
-            expected = 'Failure: ValueError: %s' % msg.encode('utf-8')
-        else:
-            expected = u'Failure: ValueError: \xc8'
+        self.assertEqual(str(excp), fail.exception_str)
+        expected = u'Failure: ValueError: \xc8'
         self.assertEqual(expected, str(fail))
 
     def test_exception_non_ascii_unicode(self):
         hi_ru = u'привет'
         fail = failure.Failure.from_exception(ValueError(hi_ru))
         self.assertEqual(hi_ru, fail.exception_str)
-        self.assertIsInstance(fail.exception_str, six.text_type)
+        self.assertIsInstance(fail.exception_str, str)
         self.assertEqual(u'Failure: ValueError: %s' % hi_ru,
-                         six.text_type(fail))
+                         str(fail))
 
     def test_wrapped_failure_non_ascii_unicode(self):
         hi_cn = u'嗨'
         fail = ValueError(hi_cn)
-        self.assertEqual(hi_cn, encodeutils.exception_to_unicode(fail))
+        self.assertEqual(hi_cn, str(fail))
         fail = failure.Failure.from_exception(fail)
         wrapped_fail = exceptions.WrappedFailure([fail])
         expected_result = (u"WrappedFailure: "
                            "[Failure: ValueError: %s]" % (hi_cn))
-        self.assertEqual(expected_result, six.text_type(wrapped_fail))
+        self.assertEqual(expected_result, str(wrapped_fail))
 
     def test_failure_equality_with_non_ascii_str(self):
         bad_string = chr(200)
@@ -379,7 +367,6 @@ class NonAsciiExceptionsTestCase(test.TestCase):
         self.assertEqual(fail, copied)
 
 
-@testtools.skipIf(not six.PY3, 'this test only works on python 3.x')
 class FailureCausesTest(test.TestCase):
 
     @classmethod
@@ -392,7 +379,7 @@ class FailureCausesTest(test.TestCase):
             cls._raise_many(messages)
             raise e
         except RuntimeError as e1:
-            six.raise_from(e, e1)
+            raise e from e1
 
     def test_causes(self):
         f = None
@@ -467,7 +454,7 @@ class FailureCausesTest(test.TestCase):
                 self._raise_many(["Still still not working",
                                   "Still not working", "Not working"])
             except RuntimeError as e:
-                six.raise_from(e, None)
+                raise e from None
         except RuntimeError:
             f = failure.Failure()
 
