@@ -15,7 +15,7 @@
 #    under the License.
 
 import networkx as nx
-from six.moves import cPickle as pickle
+import pickle
 
 from taskflow import test
 from taskflow.types import graph
@@ -98,6 +98,29 @@ class GraphTest(test.TestCase):
         g3 = graph.merge_graphs(g, g2)
         self.assertEqual(3, len(g3))
 
+    def test_pydot_output(self):
+        # NOTE(harlowja): ensure we use the ordered types here, otherwise
+        # the expected output will vary based on randomized hashing and then
+        # the test will fail randomly...
+        for graph_cls, kind, edge in [(graph.OrderedDiGraph, 'digraph', '->'),
+                                      (graph.OrderedGraph, 'graph', '--')]:
+            g = graph_cls(name='test')
+            g.add_node("a")
+            g.add_node("b")
+            g.add_node("c")
+            g.add_edge("a", "b")
+            g.add_edge("b", "c")
+            expected = """
+strict %(kind)s "test" {
+a;
+b;
+c;
+a %(edge)s b;
+b %(edge)s c;
+}
+""" % ({'kind': kind, 'edge': edge})
+            self.assertEqual(expected.lstrip(), g.export_to_dot())
+
     def test_merge_edges(self):
         g = graph.DiGraph()
         g.add_node("a")
@@ -128,13 +151,12 @@ class GraphTest(test.TestCase):
         self.assertRaises(ValueError,
                           graph.merge_graphs, g, g2)
 
-        def occurence_detector(to_graph, from_graph):
-            return sum(1 for node in from_graph.nodes_iter()
-                       if node in to_graph)
+        def occurrence_detector(to_graph, from_graph):
+            return sum(1 for node in from_graph.nodes if node in to_graph)
 
         self.assertRaises(ValueError,
                           graph.merge_graphs, g, g2,
-                          overlap_detector=occurence_detector)
+                          overlap_detector=occurrence_detector)
 
         g3 = graph.merge_graphs(g, g2, allow_overlaps=True)
         self.assertEqual(3, len(g3))
@@ -553,20 +575,20 @@ CEO
         self.assertEqual(root.child_count(only_direct=False) + 1, len(g))
         for node in root.dfs_iter(include_self=True):
             self.assertIn(node.item, g)
-        self.assertEqual([], g.predecessors('animal'))
-        self.assertEqual(['animal'], g.predecessors('reptile'))
-        self.assertEqual(['primate'], g.predecessors('human'))
-        self.assertEqual(['mammal'], g.predecessors('primate'))
-        self.assertEqual(['animal'], g.predecessors('mammal'))
-        self.assertEqual(['mammal', 'reptile'], g.successors('animal'))
+        self.assertEqual([], list(g.predecessors('animal')))
+        self.assertEqual(['animal'], list(g.predecessors('reptile')))
+        self.assertEqual(['primate'], list(g.predecessors('human')))
+        self.assertEqual(['mammal'], list(g.predecessors('primate')))
+        self.assertEqual(['animal'], list(g.predecessors('mammal')))
+        self.assertEqual(['mammal', 'reptile'], list(g.successors('animal')))
 
     def test_to_digraph_retains_metadata(self):
         root = tree.Node("chickens", alive=True)
         dead_chicken = tree.Node("chicken.1", alive=False)
         root.add(dead_chicken)
         g = root.to_digraph()
-        self.assertEqual(g.node['chickens'], {'alive': True})
-        self.assertEqual(g.node['chicken.1'], {'alive': False})
+        self.assertEqual(g.nodes['chickens'], {'alive': True})
+        self.assertEqual(g.nodes['chicken.1'], {'alive': False})
 
 
 class OrderedSetTest(test.TestCase):
