@@ -20,7 +20,6 @@ import copy
 import logging
 
 from oslo_utils import reflection
-import six
 
 LOG = logging.getLogger(__name__)
 
@@ -123,6 +122,9 @@ class Listener(object):
         else:
             return NotImplemented
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
 
 class Notifier(object):
     """A notification (`pub/sub`_ *like*) helper class.
@@ -161,7 +163,7 @@ class Notifier(object):
         :rtype: number
         """
         count = 0
-        for (_event_type, listeners) in six.iteritems(self._topics):
+        for (_event_type, listeners) in self._topics.items():
             count += len(listeners)
         return count
 
@@ -209,9 +211,9 @@ class Notifier(object):
             try:
                 listener(event_type, details.copy())
             except Exception:
-                LOG.warn("Failure calling listener %s to notify about event"
-                         " %s, details: %s", listener, event_type,
-                         details, exc_info=True)
+                LOG.warning("Failure calling listener %s to notify about event"
+                            " %s, details: %s", listener, event_type,
+                            details, exc_info=True)
 
     def register(self, event_type, callback,
                  args=None, kwargs=None, details_filter=None):
@@ -232,10 +234,10 @@ class Notifier(object):
         :param kwargs: key-value pair arguments
         :type kwargs: dictionary
         """
-        if not six.callable(callback):
+        if not callable(callback):
             raise ValueError("Event callback must be callable")
         if details_filter is not None:
-            if not six.callable(details_filter):
+            if not callable(details_filter):
                 raise ValueError("Details filter must be callable")
         if not self.can_be_registered(event_type):
             raise ValueError("Disallowed event type '%s' can not have a"
@@ -277,7 +279,7 @@ class Notifier(object):
     def copy(self):
         c = copy.copy(self)
         c._topics = collections.defaultdict(list)
-        for (event_type, listeners) in six.iteritems(self._topics):
+        for (event_type, listeners) in self._topics.items():
             c._topics[event_type] = listeners[:]
         return c
 
@@ -289,7 +291,7 @@ class Notifier(object):
         itself wraps a provided callback (and its details filter
         callback, if any).
         """
-        for event_type, listeners in six.iteritems(self._topics):
+        for event_type, listeners in self._topics.items():
             if listeners:
                 yield (event_type, listeners)
 
