@@ -14,28 +14,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from concurrent import futures
-
-from taskflow.utils import eventlet_utils as eu
-
-
-def wait_for_any(fs, timeout=None):
-    """Wait for one of the futures to complete.
-
-    Works correctly with both green and non-green futures.
-
-    Returns pair (done, not_done).
-    """
-    any_green = any(isinstance(f, eu.GreenFuture) for f in fs)
-    if any_green:
-        return eu.wait_for_any(fs, timeout=timeout)
-    else:
-        return tuple(futures.wait(fs, timeout=timeout,
-                                  return_when=futures.FIRST_COMPLETED))
+import futurist
 
 
 def make_completed_future(result):
-    """Make with completed with given result."""
-    future = futures.Future()
+    """Make and return a future completed with a given result."""
+    future = futurist.Future()
     future.set_result(result)
     return future
